pub struct DictionaryValue {
pub attribute_name: String,
pub name: String,
pub value: u64,
}Expand description
A mapping between a string name and a numeric value for an attribute.
Fields
attribute_name: StringThe name of the attribute this value belongs to.
name: StringThe name of the specific value (e.g., “Access-Request”).
value: u64The numeric representation of the value.